@@ -38,7 +38,7 @@ class TestUpgrade(unittest.TestCase):
             dlg.upgrade()
             execl.assert_called_once_with(
                 "/bin/sh", "/bin/sh", "-c",
-                "/usr/bin/pkexec /usr/bin/do-release-upgrade "
+                "/usr/bin/do-release-upgrade "
                 "--frontend=DistUpgradeViewGtk3 -d -p")
 
 
